@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.23 2002/09/19 03:15:31 mmclouglin Exp $ */
+/* $Id: gweather-dialog.c,v 1.24.2.1 2003/03/10 16:22:55 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -80,9 +80,9 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   				   GTK_RESPONSE_CLOSE);
 
   if (gw_applet->gweather_pref.radar_enabled)
-      gtk_widget_set_usize (gw_applet->gweather_dialog, 570, 440);
+      gtk_window_set_default_size (GTK_WINDOW(gw_applet->gweather_dialog), 570,440);
   else
-      gtk_widget_set_usize (gw_applet->gweather_dialog, 590, 340);
+      gtk_window_set_default_size (GTK_WINDOW(gw_applet->gweather_dialog), 590, 340);
 
   gtk_window_set_screen (GTK_WINDOW (gw_applet->gweather_dialog),
 			 gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
@@ -350,6 +350,7 @@ void gweather_dialog_open (GWeatherApplet *gw_applet)
     if (!gw_applet->gweather_dialog)
         gweather_dialog_create(gw_applet);
     gweather_dialog_update(gw_applet);
+    gtk_window_set_resizable(GTK_WINDOW(gw_applet->gweather_dialog), TRUE);
     gtk_widget_show(gw_applet->gweather_dialog);
 }
 
